@@ -88,8 +88,10 @@ the same terms as the Perl 5 programming language system itself.
 
 use namespace::clean;
 use Catmandu::Sane;
-use Archive::BagIt;
-use File::Path qw(make_path remove_tree);
+use Catmandu::BagIt;
+use File::Path qw(mkpath);
+use File::Temp qw(tempfile);
+use IO::File;
 use LWP::Simple;
 use Moo;
 
@@ -108,16 +110,12 @@ sub add {
 
 	  Catmandu::Error->throw("$directory exists") if -d $directory && ! $self->overwrite;
 
-    my ($bag,$isnew) = $self->write_bag($directory);
+    my $bagit = Catmandu::BagIt->new();
 
     if (exists $data->{tags}) {
-        my $tags = $data->{tags};
-
-        # These will be generated by Archive::BagIt...
-        delete $tags->{'Bagging-Date'};
-        delete $tags->{'Bag-Software-Agent'};
-        
-        $bag->_write_baginfo($directory,%$tags);
+        for my $tag (keys %{$data->{tags}}) {
+            $bagit->add_info($tag,$data->{tags}->{$tag});
+        }
     }
 
     if (exists $data->{fetch}) {
@@ -125,54 +123,24 @@ sub add {
             my ($url) = keys %$fetch;
             my $file  = $fetch->{$url};
 
+            mkpath("$directory/data") unless -d "$directory/data";
+
+            my ($fh, $filename) = tempfile();
+
             # For now using a simplistic mirror operation
-            unless ((my $code = mirror($url,"$directory/$file")) == RC_OK) {
-                Catmandu::Error->throw("failed to mirror $url to $directory/$file : $code ");
+            unless ((my $code = mirror($url,$filename)) == RC_OK) {
+                Catmandu::Error->throw("failed to mirror $url to $filename : $code ");
             }
 
-            $isnew = 0;
+            $file =~ s{^data/}{};
+            $bagit->add_file($file,IO::File->new($filename));
+            $bagit->write($directory, overwrite => 1);
         }
     }
 
-    if ($isnew) {}
-    elsif ($self->skip_manifest) {}
-    else {
-        $bag->_manifest_md5($directory);
-    }
-
-    $bag->_tagmanifest_md5($directory);
-
     1;
 }
 
-sub write_bag {
-    my ($self,$directory) = @_;
-
-    my $isnew = 1;
-	  my $bag;
-
-	  # If the directory contains a bagit.txt file we assume it is already a bag
-	  if (-d $directory && -d $directory . "bagit.txt") {
-        $bag = Archive::BagIt->new($directory);
-        $isnew = 0;
-    }
-    elsif (-d $directory) {
-    	  $bag = Archive::BagIt->make_bag($directory);
-        $isnew = 0;
-    }
-    else {
-    	  make_path($directory, { error => \my $err });
-
-    	  Catmandu::Error->throw("$directory creation failed") if @$err;
-    	 
-    	  $bag = Archive::BagIt->make_bag($directory);
-
-        $isnew = 1;
-    }
-
-    ($bag,$isnew);
-}
-
 sub commit { 1 }
 
 1;
\ No newline at end of file
